@@ -153,13 +153,13 @@ from kivy.uix.widget import Widget
 from ae.base import snake_to_camel                                                                      # type: ignore
 from ae.inspector import try_eval                                                                       # type: ignore
 from ae.gui_help import (                                                                               # type: ignore
-    anchor_layout_x, anchor_layout_y, anchor_points, anchor_spec, help_id_tour_class,
-    HelpAppBase, OnboardingTour, TourBase, REGISTERED_TOURS)
+    REGISTERED_TOURS, anchor_layout_x, anchor_layout_y, anchor_points, anchor_spec, help_id_tour_class,
+    HelpAppBase, OnboardingTour, TourBase)
 from ae.kivy_glsl import ShaderIdType, ShadersMixin                                                     # type: ignore
 from ae.kivy_relief_canvas import ReliefCanvas                                                          # type: ignore
 
 
-__version__ = '0.2.31'
+__version__ = '0.2.32'
 
 
 # load/declared help/tour widgets, based-on Kivy core widgets (without any features from ae.kivy_app/widgets.kv)
@@ -588,6 +588,9 @@ class HelpToggler(ReliefCanvas, Image):
 # ============================   app tours   ==========================================================================
 
 
+DEF_FADE_OUT_APP = 0.39                                             #: default of tour layout fade out app screen factor
+
+
 PageAnimationType = Tuple[str, Union[Animation, str]]
 """ tuple of a widget id string and an :class:`~kivy.animation.Animation` instance/evaluation-expression.
 
@@ -612,6 +615,18 @@ WidgetValues = Dict[str, Union[list, tuple, dict, float]]
 """ a key of this dict specifies the name, the dict value the value of a widget property/attribute. """
 
 
+def ani_start_check(ani: Animation, wid: Widget):
+    """ start animation if needed else skip animation start.
+
+    :param ani:                 :class:`~kivy.animation.Animation` instance.
+    :param wid:                 widget to start/skip the animation for.
+    """
+    for attr, value in ani.animated_properties.items():
+        if getattr(wid, attr) != value:
+            ani.start(wid)
+            break
+
+
 def animated_widget_values(wid: Widget, ani: Union[Animation, CompoundAnimation]) -> WidgetValues:
     """ determine from a widget the attribute/property values animated/changed by an animation.
 
@@ -1065,6 +1080,14 @@ class TourOverlay(ModalBehavior, ShadersMixin, FloatLayout):
     :attr:`explained_widget` is a :class:`~kivy.properties.ObjectProperty` and is read-only.
     """
 
+    fade_out_app = NumericProperty(DEF_FADE_OUT_APP)
+    """ fade out app screen factor: 0.0 prevents fade out of the areas around TourPageTexts and the explained widget.
+
+    1.0 results in maximum app screen fade out. configurable for individual tour page via `page_data['fade_out_app']`.
+
+    :attr:`fade_out_app` is a :class:`~kivy.properties.NumericProperty` and defaults to 0.39.
+    """
+
     label_height = NumericProperty()
     """ height in pixels of the page text labels and text lines.
 
@@ -1110,6 +1133,16 @@ class TourOverlay(ModalBehavior, ShadersMixin, FloatLayout):
         self.tour_instance.cancel_auto_page_switch_request()
         self.tour_instance.next_page()
 
+    def on_navigation_disabled(self, *_args):
+        """ navigation button disabled change event, used to hide page texts (blend-in-anim in page_updated()). """
+        if self.navigation_disabled:
+            ani = Animation(opacity=0.123, d=0.6)
+            ids = self.ids
+            ani_start_check(ani, ids.tour_page_texts)
+            ani_start_check(ani, ids.prev_but)
+            ani_start_check(ani, ids.next_but)
+            ani_start_check(ani, ids.stop_but)
+
     def page_updated(self):
         """ callback from :meth:`~TourBase.setup_layout` for UI-specific patches, after tour layout/overlay setup. """
         tooltip = self.ids.tooltip
@@ -1121,7 +1154,17 @@ class TourOverlay(ModalBehavior, ShadersMixin, FloatLayout):
             pos2 = max(exp_y + self.explained_size[1], tooltip.top)
             if pos1 < win_height - pos2:
                 nav_y = max(nav_y + pos2, win_height - self.ids.tour_page_texts.height)
-        Animation(navigation_pos_hint_y=nav_y / win_height, t='in_out_sine', d=3).start(self)
+
+        ani_kwargs = dict(t='in_out_sine', d=2.1)
+        ani_start_check(Animation(fade_out_app=self.tour_instance.page_data.get('fade_out_app', DEF_FADE_OUT_APP),
+                                  navigation_pos_hint_y=nav_y / win_height,
+                                  **ani_kwargs),
+                        self)
+        ani = Animation(opacity=1.0, **ani_kwargs)
+        ani_start_check(ani, self.ids.tour_page_texts)
+        ani_start_check(ani, self.ids.prev_but)
+        ani_start_check(ani, self.ids.next_but)
+        ani_start_check(ani, self.ids.stop_but)
 
         self.navigation_disabled = False
 
